@@ -29,6 +29,8 @@ Mail::Sendmail
 CGI
 Data::Dumper
 YAML
+JSON
+RPC::XML
 
 =head1 AUTHOR
 
